package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````(`*``!````W!0!`#0```#,`@$```0`!30`(``)
M`"@`'``;``$``'`0A```$(0!`!"$`0`(````"`````0````$````!@```#0`
M```T``$`-``!`"`!```@`0``!`````0````#````5`$``%0!`0!4`0$`&0``
M`!D````$`````0````$````````````!`````0`<A```'(0```4```````$`
M`0```/S^``#\_@(`_/X"`"P"``!0`@``!@```````0`"````"/\```C_`@`(
M_P(`^````/@````&````!`````0```!P`0``<`$!`'`!`0!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71D_/X`
M`/S^`@#\_@(`!`$```0!```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````%`````,```!'3E4`D`:5-1>`,`MV"W-Q9/A<7MFT"?8$
M````$`````$```!'3E4```````,````"`````````'8````%````$`````D`
M``"@"*0"@>4#D@@*RD`&40`Y@@`"1PHA`!&D0```!+K`D`*``@@0D$`D0B""
M(0``P"!```$TP&0`"!07!)P@D4*@``````4`````````!@`````````'````
M```````````(````"0````H````+````#0`````````````````````````.
M``````````\````0`````````````````````````!$````3`````````!0`
M````````%0`````````````````````````6````%P```!@`````````````
M````````````&0```!H``````````````!L`````````'````!X`````````
M`````!\````@`````````"$````C````)````"4`````````)@```"@````I
M````*@```"L````L````````````````````+0```"X``````````````"\`
M```P````,0```#(````S````-````#4``````````````#8`````````````
M````````````````````````````````````````````-P`````````Y````
M.P```#T````^````/P```$$```````````````````!"````````````````
M````0P```$0``````````````````````````````$4`````````1@```,DY
M0!\+BA!7][[\D>G[P\*'\)9\D76"#6"8[Q+M+/:+8]#Z@C]^EGP;G]:])76"
M#3Z>0D3)U;)QTU$$A.W>DQS/2J[_IYN3''V0$.FM<`ZO+TX]]BT.L7-9.T`?
M*M#A(NT_D`(]K3D-(6)D![N5DQSJA(H<5]N3',..A_]1[A'CS3\,KYA"[J&?
M(L>HHUKOD'=OXW"C`O89+=_^2)DBU&A!39U\V_<`7@>DA_\QN((-G;N3'*?=
MHVL!(_FDO=!+?5$;?5]O>FGZ!#*EA8%T@@U\[1$/>_!*:_8CSB#%N9Q`[PM1
M^5^6DQS>A2!/0V9+$/W2[P]7DEI2A_F<@1?J6O''#N`].?*+'```````````
M```````````!```````````````@````$```````````````(````"P`````
M`````````"`````,`0`````````````6````G0$`````````````$@```$8`
M```X`0,``0```!$`&`!6`@`````````````2````*@$`````````````$@``
M`$0!`````````````!(```"I`@`````````````2````U0$`````````````
M$@```$D!`````````````!(````?`0`````````````2````K@$`````````
M````$@```.L!`````````````!(```"%`@`````````````2````@```````
M````````$@```'P!```H$`$``````!(```"P```````````````2````\P$`
M````````````$@```/H!`````````````!(```#%`0`````````````2````
M7`$`````````````$@```-P!`````````````!(```!>`@`````````````2
M````CP$`````````````$@```&L!`````````````!(```"[`0``````````
M```2````C```````````````$@```%4!`````````````!(```#R`@``!/\"
M``0````1`!0`?@(`````````````$@```%<"`````````````!(````5`@``
M```````````2````(@(`````````````$@```$@"`````````````!(```#.
M`@`````````````2````]0``````````````$@```#H"`````````````!(`
M``"S`0`````````````2````DP(`````````````$@```%,`````````````
M`!(```"G```````````````2````/P$`````````````$@```!`"````````
M`````!(```#,`0`````````````2````FP(`````````````$@```(P"````
M`````````!(````#`@`````````````2````V`(``"@!`P`$````(0`8`+<"
M`````````````!(```#8```````````````2````NP``````````````$@``
M`.`"`````````````!(```#G```````````````2````=P(`````````````
M$@```,@"`````````````!(```"7````W!`!```````2````Y`$`````````
M````$@```-8"```H`0,`!````!$`&``I`@`````````````2````L`(`````
M````````$@```,D``````````````!(````*`@`````````````2````'`(`
M````````````$@```&,``````````````!(```!O````Z!`!```````2````
MH@(`````````````$@```#("`````````````!(```!P`@``,`$#``0````1
M`!@``%]?9VUO;E]S=&%R=%]?`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L
M90!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`%!,7V1O7W5N9'5M<`!097)L
M7V=V7V9E=&-H<'8`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?;&]C:P!097)L
M7V=E=%]S=@!097)L7VYE=UA3`&)O;W1?1'EN84QO861E<@!P97)L7W)U;@!P
M97)L7W!A<G-E`%!E<FQ?<W9?<V5T<'8`4&5R;%]S=E]S971P=FX`<&5R;%]C
M;VYS=')U8W0`<&5R;%]D97-T<G5C=`!097)L7V-R;V%K7VUE;6]R>5]W<F%P
M`%!,7V-U<G)E;G1?8V]N=&5X=`!P97)L7V%L;&]C`%!E<FQ?8W)O86M?;F]C
M;VYT97AT`'!E<FQ?9G)E90!097)L7W-A9F5S>7-M86QL;V,`4&5R;%]S>7-?
M:6YI=#,`4&5R;%]N97=84U]F;&%G<P!097)L7V%T9F]R:U]U;FQO8VL`4&5R
M;%]S>7-?=&5R;0!?7W-T86-K7V-H:U]F86EL`&5X:70`;'-E96LV-`!R96%D
M9&ER-C0`<W1R9'5P`&-L;W-E9&ER`&]P96XV-`!S=')R8VAR`'5N;&EN:P!M
M96UM;W9E`'-T<G1O:P!G971P=W5I9`!S=')L96X`<FUD:7(`<F5A9`!S=')S
M='(`;6MD:7(`9V5T<&ED`')E861L:6YK`')E86QL;V,`7U]S<')I;G1F7V-H
M:P!?7V9P<FEN=&9?8VAK`&QS=&%T-C0`7U]L:6)C7W-T87)T7VUA:6X`<W1D
M97)R`&UE;6-H<@!S=')C:'(`;65M8VUP`&UE;7-E=`!O<&5N9&ER`&=E='5I
M9`!A8V-E<W,`;65M8W!Y`'-T<F-M<`!?7V5R<FYO7VQO8V%T:6]N`&%B;W)T
M`'-T<FYC;7``7U]E;G9I<F]N`%]?<F5G:7-T97)?871F;W)K`%]?<W1A8VM?
M8VAK7V=U87)D`&QI8G!E<FPN<V\N-2XS-@!L:6)C+G-O+C8`;&0M;&EN=7@M
M87)M:&8N<V\N,P!'3$E"0U\R+C0`1TQ)0D-?,BXS-`!'3$E"0U\R+C,S````
M`0`!``$``0`"``$``P`!``(``@`"``$``0`"``(``@`!``$``0`"``(``@`!
M``(`!0`!``$``@`!``(`!``"``,``@`"``(``@`!``(``@`"``$``0`!``(`
M`@`"``(``@`"``(``0`!``(``0`"``(``0`"``(``@`"``$``@`"``$``0`"
M``(``@`!``$`'@,``!`````@````%&EI#0``!``R`P````````$``P`4`P``
M$`````````"TD98&```%`#P#```0````LY&6!@```P!'`P``$````!1I:0T`
M``(`,@,````````$`0,`%0$```@!`P`3!```!/\"`!0?```H`0,`%#P``#`!
M`P`41@``.`$#`!0&```,``,`%D$``!```P`6+```%``#`!8Y```8``,`%BD`
M`!P``P`6$```(``#`!81```D``,`%A,``"@``P`6$@``+``#`!8!```P``,`
M%B```#0``P`6*P``.``#`!8J```\``,`%C```$```P`6-0``1``#`!88``!(
M``,`%@T``$P``P`6+P``4``#`!8)``!4``,`%BT``%@``P`61```7``#`!8A
M``!@``,`%AH``&0``P`6.@``:``#`!9#``!L``,`%AL``'```P`6-```=``#
M`!8Q``!X``,`%CL``'P``P`6"@``@``#`!85``"$``,`%C\``(@``P`6"P``
MC``#`!8B``"0``,`%C<``)0``P`6+@``F``#`!8F``"<``,`%A8``*```P`6
M0@``I``#`!8H``"H``,`%AX``*P``P`6!0``L``#`!8D``"T``,`%A0``+@`
M`P`60```O``#`!8'``#```,`%@\``,0``P`6-@``R``#`!8(``#,``,`%B,`
M`-```P`6#```U``#`!8]``#8``,`%AP``-P``P`6)P``X``#`!8E``#D``,`
M%AT``.@``P`610``[``#`!87``#P``,`%AD``/0``P`6.```^``#`!8^``#\
M``,`%@X````!`P`6,P``"$`MZ5@!`.L(@+WH!.`MY03@G^4.X(_@"/"^Y3#P
M`0``QH_B'\J,XC#PO.4`QH_B'\J,XBCPO.4`QH_B'\J,XB#PO.4`QH_B'\J,
MXACPO.4`QH_B'\J,XA#PO.4`QH_B'\J,X@CPO.4`QH_B'\J,X@#PO.4`QH_B
M'LJ,XOC_O.4`QH_B'LJ,XO#_O.4`QH_B'LJ,XNC_O.4`QH_B'LJ,XN#_O.4`
MQH_B'LJ,XMC_O.4`QH_B'LJ,XM#_O.4`QH_B'LJ,XLC_O.4`QH_B'LJ,XL#_
MO.4`QH_B'LJ,XKC_O.4`QH_B'LJ,XK#_O.4`QH_B'LJ,XJC_O.4`QH_B'LJ,
MXJ#_O.4`QH_B'LJ,XIC_O.4`QH_B'LJ,XI#_O.4`QH_B'LJ,XHC_O.4`QH_B
M'LJ,XH#_O.4`QH_B'LJ,XGC_O.4`QH_B'LJ,XG#_O.4`QH_B'LJ,XFC_O.4`
MQH_B'LJ,XF#_O.4`QH_B'LJ,XEC_O.4`QH_B'LJ,XE#_O.4`QH_B'LJ,XDC_
MO.4`QH_B'LJ,XD#_O.4`QH_B'LJ,XCC_O.4`QH_B'LJ,XC#_O.4`QH_B'LJ,
MXBC_O.4`QH_B'LJ,XB#_O.4`QH_B'LJ,XAC_O.4`QH_B'LJ,XA#_O.4`QH_B
M'LJ,X@C_O.4`QH_B'LJ,X@#_O.4`QH_B'LJ,XOC^O.4`QH_B'LJ,XO#^O.4`
MQH_B'LJ,XNC^O.4`QH_B'LJ,XN#^O.4`QH_B'LJ,XMC^O.4`QH_B'LJ,XM#^
MO.4`QH_B'LJ,XLC^O.4`QH_B'LJ,XL#^O.4`QH_B'LJ,XKC^O.4`QH_B'LJ,
MXK#^O.4`QH_B'LJ,XJC^O.4`QH_B'LJ,XJ#^O.4`QH_B'LJ,XIC^O.4`QH_B
M'LJ,XI#^O.4`QH_B'LJ,XHC^O.4`QH_B'LJ,XH#^O.4`QH_B'LJ,XGC^O.4`
MQH_B'LJ,XG#^O.4`QH_B'LJ,XFC^O.4`QH_B'LJ,XF#^O.4`QH_B'LJ,XEC^
MO.4`QH_B'LJ,XE#^O.4`QH_B'LJ,XDC^O.4`````<$`MZ00RG^4@T$WB%`"-
MY10`C>(0$(WE$!"-X@P@C>4,((WB`#"3Y1PPC>4`,*#CW___ZR@@`>,!($#C
M`A"@X>@``>,!`$#CC`L`ZS@Q`.,#,$#C`$#3Y0``5.-'```*<"\=[J@QG^44
M8)WE!`"&X@-@AN(#,)_G!P%PXP,@DN?&,]+E`S"#X\8SPN59``"*``&@X3Q1
M`.,#4$#CK___ZQ!`G>4`,*#A!`"%Y0`@E.4`((#EZ"0$XP$@0.,$((#E&"$`
MXP,@0.,,()+E"""`Y>PD!.,!($#C#""`Y10`G>4!`%#C1```V@00A.(,P(/B
M`$&$X`3@D>0$X*SE`0!4X?O__QH#`(#B`!"@XP`0C>4&(*#A`!&#YPP`E>7,
M'`'C`1!`XPS__^L`0%#B(```"@P`E>59___K&!"-XK0"!.,!`$#C<@``ZP``
M4.,<```*#`"5Y?'^_^LL___KK#"?Y0`@D^4<,)WE`B`SX``PH.,E```:!`"@
MX2#0C>)P@+WH$/__ZSPA`.,#($#C``!0XPP`@N4:```**/__ZW0PG^5P+QWN
M`S"?YP,PDN=[1\/EJ___Z@P`E>7S_O_K`$"@X=K__^H(`)7E``!0XP$```KR
M!@#KW?__ZA@0C>)0`@3C`0!`XTH``.L``%#C"`"%Y=;__PKU___J+O__ZP0`
MH./`___J`0"@XW7__^LX___K!/\"`,SM`0"<[`$``+"@XP#@H.,$$)WD#2"@
MX00@+>4$`"WE'*"?Y1@PC^(#H(K@`#"@XP0P+>4,`)_E``":YUK__^NT_O_K
MZ.H!``P!```4,)_E%""?Y0,PC^`"()/G``!2XQ[_+P&]_O_JT.H!``0!```H
M`0#C`P!`XR@Q`.,#,$#C``!3X1[_+P$`,`#C`#!`XP``4^,>_R\!$_\OX2@!
M`.,#`$#C*#$`XP,P0.,`,$/@HQ^@X4,1@>#!$+#A'O\O`0`P`.,`,$#C``!3
MXQ[_+P$3_R_A$$`MZ3E!`.,#0$#C`##4Y0``4^,0@+T8W___ZP$PH.,`,,3E
M$("]Z.;__^KP1RWI`(!0XBL```HH,0#C`S!`XP"0D^4``%GC*```"@!0V.4!
M<*#A``!5XST`51,!4*`3`%"@`Q$``!H`0)GE``!4XPP```H)8*#A!`"@X04@
MH.$($*#A!___ZP``4.,"```:!3#4YST`4^,+```*!$"VY0``5./S__\:!`"@
MX?"'O>@(4*#A`3#UY0``4^,]`%,3^___&@A01>#F___J"6!&X`%0A>(%0(3@
M1F&@X00`H.$`8(?E\(>]Z`A`H.'M___J"4"@X>O__^H00"WI`$"@X7`PG^5P
MT$WB#1"@X0`PD^5L,(WE`#"@X\?^_^L``%#C``"@$P0``!H0,)WE#SH#X@H*
M4^,!"5,3!P``"C0PG^4`()/E;#"=Y0(@,^``,*#C!P``&G#0C>(0@+WH`A"@
MXP0`H.%I_O_K$`]OX:`"H.'Q___JI/[_ZP3_`@#P0"WI`&!0XD`QG^5\T$WB
M`#"3Y70PC>4`,*#C`@``"@`PUN4``%/C!P``&APQG^4`()/E=#"=Y0(@,^``
M,*#C00``&GS0C>+P@+WH(/[_ZP!`4.+T__\*!`"@X:S^_^L``%#C*@``"A,P
MT.434(#B+@!3XP(``!H!,-7E``!3X_3__PH3,-#E+@!3XR4```H&`*#A4_[_
MZP!PH.$%`*#A4/[_ZP``A^`"`(#B=/[_ZP$0H.,`<*#A`"#@XP10C>7P,03C
M`3!`XP!@C>63_O_K"!"-X@<`H.$P_O_K`0!PXP<`H.$#```*&#"=Y0\Z`^(!
M"5/C$@``"CW^_^L'`*#A'?[_ZP0`H.&!_O_K``!0X]3__QH$`*#A2O[_ZP8`
MH.%C_O_KP/__Z@$PU>4N`%/CUO__&@(PU>4``%/CQ?__"M+__^JM___KZ___
MZD_^_^L$_P(`\$\MZ0(0H.,`(*#C`=A-X@`PH.,<T$WB`)"@X0'HC>(4X([B
M`!"-Y1P1G^4`$)'E`!".Y0`0H.,Y_O_K`0!0X@"`P>+(+Z#A`C`@X`(P4^!S
M,/_F`C`CX`(P4^`"(,+@`V!0X`*`R.```%CC,@``N@B@H.,!H$#C`+"@X_^_
M3^,8<0#C`W!`XPQ0C>((,*#A`!"@XP8@H.$)`*#A`!"-Y1_^_^L*(*#A!1"@
MX0D`H.'?_?_K!P!0XQH``)H(`$#B`$"5X`,``#H6``#J`4!$X@4`5.$3```Z
M"""@XP<0H.$$`*#AJ/W_ZP``4./V__\:!4!$X`8`E.#$'ZC@`<B-XD0PG^44
MP(SB`""3Y0`PG.4"(#/@`#"@XPH``!H!V(WB'-"-XO"/O>@!:%;B`(#(X@$`
M>.,+`%8!T___&@``X.,`$*#A[/__ZOO]_^L$_P(`<$`MZ0!@H.'D,)_E`=I-
MX@%0H.$(T$WB_R\`XP$*C>($$(WB!`"`X@`PD^4`,(#E`#"@X_@!!.,!`$#C
M"/[_ZP!`4.('``#:`2!$X@@PC>(",(/@!#!3Y0``4^,4```:``!2XQ$``!J(
M,)_E<`\=[@4@H.$&$*#A`S"?YP,`D.>(_?_K`1J-XF0PG^4$$('B`""3Y0`P
MD>4"(#/@`#"@XQ(``!H!VHWB"-"-XG"`O>@"0*#A!""@X2\0H.,$`(WB__W_
MZP``4./F__\**`"?Y7#/'>X$,*#A!""-X@80H.$``)_G``"<YZ']_^OD___J
MO?W_ZP3_`@#`Y@$`6.8!`/!'+>D!0*#A\#&?Y0C03>(`4*#A`#"3Y00PC>4`
M,*#C`##1Y3T`4^,!0($"!`"@X8/]_^L-$*#A`&"@X04`H.&Q_O_K`)!0XCT`
M``I\_?_K``!6X30``)H`@)WE*'$`XP-P0.,(@:#A`##5Y0``4^,]`%,3`3"@
M$P`PH`,%```*!3"@X0$@\^4``%+C/0!2$_O__QH%,$/@`@"&X@!@E^4#`(#@
MC?W_ZP``4.,(`(;G%0``"@`PE^4%`*#A"!"3YP$PT.0`,,'E``!3XST`4Q,&
M```*`2"!X@$PT.0"$*#A`3#"Y#T`4^,``%,3^?__&@$@H.$],*#C`##!Y0$P
MU.0!,.+E``!3X_O__QKL,)_E`""3Y00PG>4"(#/@`#"@XS4``!H(T(WB\(>]
MZ`&02>(!,-3D`3#IY0``4^/[__\:\?__ZBAQ`.,#<$#C`("7Y0`PF.4``%/C
M)```"@@PH.$$(+/E"1"@X0&0B>(``%+C^O__&@,0@>(!$:#A/#$`XP,P0.,`
M()/E``!2XP\``!H!`*#A`2"@XP`@@^5/_?_K`*!0XMC__PH($*#A"8&@X0@@
MH.%;_?_K`*"'Y0"0C>4!D(GB`#"@XPDQBN>E___J"`"@X7']_^L`H*#A``!0
MXP``A^7(__\*"8&@X?+__^H#D*#A"!"@X]___^HZ_?_K!/\"`&@`G^4\,PCC
M`3!`XQ!`+>EP3QWN"-!-XMP@`>,!($#C``"?YP@2!.,!$$#C``"4YU;]_^LX
M$)_E`,"@X^0T!.,!,$#C^"T"XP$@0.,!$)_G`0"4YR02!.,!$$#C!,"-Y0`P
MC>7O_/_K"-"-XA"`O>@4Y`$`Z.,!`"0`G^5PSQWN/#,(XP$P0./<(`'C`2!`
MXP@2!.,!$$#C``"?YP``G.<Z_?_JG.,!`#!`+>G(,)_E`MI-XAS03>("&HWB
M%!"!X@`PD^4`,('E`#"@XQW]_^L!$*#C`,"@X0$@`>,`P(WE#`"-XD@R!.,!
M,$#C!#"-Y3PR!.,!,$#C'OW_ZP$:C>(!*J#C$!"!X@P`C>(3_?_K`$!0XA8`
M`+H!`(3B[OS_ZP!04.(2```*`1J-X@0@H.$0$('BQ_S_ZP`PH.,$,,7G`AJ-
MXC`PG^44$('B`""3Y0`PD>4"(#/@`#"@XP,``!H%`*#A`MJ-XAS0C>(P@+WH
MW/S_ZP!0H./P___J!/\"`,C__^KP0RWI`&"@X1`RG^5"W4WB`4"@X0303>)0
M`@3C`0!`XT'-C>(0$(WB/,",X@`PD^4`,(SE`#"@X]']_^LO$*#C`%"@X08`
MH.%H_/_K``!0XP\```H&$*#A7`($XP$`0.,$___K!@"@X4$=C>*L,9_E/!"!
MX@`@D^4`,)'E`B`SX``PH.-D```:0MV-X@30C>+P@[WH!`"@X:7\_^ML$@3C
M`1!`X[3\_^L`0%#BZ/__"@`PU.5X@@3C`8!`XWQPC>(``%/C.P``"@``5>,$
M```*!!"@X04`H.':_/_K``!0XRL```H$`*#A<_S_ZP$@0.("((3@`#"@X0(`
M5.$`D*#A`#"$,``0H#,!`(0R`P``.@@``.H#`%#A`!##Y0(```H!('/E+P!2
MX_G__PH$`*#A8?S_ZP"0H.$&`*#A7OS_ZPD`@.`!`(#B`0I0X\#__RH!*J#C
M`1"@XP<`H.$(8(WE$`&-Z'`R!.,!,$#CH/S_ZQ`0C>('`*#A/?S_ZP``4.,#
M```:(#"=Y0\Z`^(""5/C%0``"@``H.-L$@3C`1!`XW7\_^L`0%#BJ?__"@`P
MU.4``%/CP___&@``5>,"```*`##5Y2X`4^,#```*3$($XP%`0.,!D*#CUO__
MZ@$PU>4``%/CZO__"O?__^H!$*#C!P"@X1O\_^L``%#CY/__&@<0H.%<`@3C
M`0!`XYG^_^L'`*#A1OS_ZY+__^I0_/_K!/\"`!!`+>DO$*#C`$"@X?W[_^L`
M`%#C`4"`$@0`H.$00+WH.OS_ZG!`+>D`8%#B%#&?Y0':3>((T$WB`1J-X@00
M@>(`,)/E`#"!Y0`PH.,L```*`##6Y0``4^,I```*#?S_ZP$@@.(`0*#A`0I2
MXS(``(H$4(WB!A"@X04`H.$+_/_K`3!$X@,PA>`%`%/A!P``F@`0H.,"``#J
M!0!3X0$0P^4"```*`2!3Y"\`4N/Y__\*+Q"@XP4`H.'2^__K``!0XP\```H%
M`%#A`#"@@P`PP(4%`*#A#?S_ZP$:C>)D,)_E!!"!X@`@D^4`,)'E`B`SX``P
MH.,2```:`=J-X@C0C>)P@+WH`1J-XC@PG^4$$('B`""3Y0`PD>4"(#/@`#"@
MXP<``!I,`@3C`0!`XP':C>((T(WB<$"]Z/3[_^H``*#CY/__ZOW[_^L$_P(`
M,$`MZ7Q"!.,!0$#CF#2?Y0S03>(H40#C`U!`XP`PD^4$,(WE`#"@XPT0H.$$
M`*#A]_S_ZP``4.,,```*``"=Y0`0E>4`,8'@!""3Y0`A@><``%+C\___"@0P
M@^($()/E!""#Y```4N/[__\:[?__ZHA"!.,!0$#C*%$`XP-00.,-$*#A!`"@
MX>'\_^L``%#C#```"@``G>4`$)7E`#&!X`0@D^4`(8'G``!2X_/__PH$,(/B
M!""3Y00@@^0``%+C^___&NW__^J00@3C`4!`XRA1`.,#4$#C#1"@X00`H.'+
M_/_K``!0XPP```H``)WE`!"5Y0`Q@>`$()/E`"&!YP``4N/S__\*!#"#X@0@
MD^4$((/D``!2X_O__QKM___JG$($XP%`0.,H40#C`U!`XPT0H.$$`*#AM?S_
MZP``4.,,```*``"=Y0`0E>4`,8'@!""3Y0`A@><``%+C\___"@0P@^($()/E
M!""#Y```4N/[__\:[?__ZJ1"!.,!0$#C*%$`XP-00.,-$*#A!`"@X9_\_^L`
M`%#C#```"@``G>4`$)7E`#&!X`0@D^4`(8'G``!2X_/__PH$,(/B!""3Y00@
M@^0``%+C^___&NW__^JT0@3C`4!`XRA1`.,#4$#C#1"@X00`H.&)_/_K``!0
MXPP```H``)WE`!"5Y0`Q@>`$()/E`"&!YP``4N/S__\*!#"#X@0@D^4$((/D
M``!2X_O__QKM___J4$($XP%`0.,H40#C`U!`XPT0H.$$`*#A<_S_ZP``4.,,
M```*``"=Y0`0E>4`,8'@!""3Y0`A@><``%+C\___"@0P@^($()/E!""#Y```
M4N/[__\:[?__ZL!"!.,!0$#C*%$`XP-00.,-$*#A!`"@X5W\_^L``%#C#```
M"@``G>4`$)7E`#&!X`0@D^4`(8'G``!2X_/__PH$,(/B!""3Y00@@^0``%+C
M^___&NW__^K,0@3C`4!`XRA1`.,#4$#C#1"@X00`H.%'_/_K``!0XPP```H`
M`)WE`!"5Y0`Q@>`$()/E`"&!YP``4N/S__\*!#"#X@0@D^4$((/D``!2X_O_
M_QKM___JV$($XP%`0.,H40#C`U!`XPT0H.$$`*#A,?S_ZP``4.,,```*``"=
MY0`0E>4`,8'@!""3Y0`A@><``%+C\___"@0P@^($()/E!""#Y```4N/[__\:
M[?__ZEQ"!.,!0$#C*%$`XP-00.,-$*#A!`"@X1O\_^L``%#C#```"@``G>4`
M$)7E`#&!X`0@D^4`(8'G``!2X_/__PH$,(/B!""3Y00@@^0``%+C^___&NW_
M_^H-$*#AY`($XP$`0.,(_/_K`!!0X@(```K,`@3C`0!`XT#]_^L-$*#A^`($
MXP$`0./_^__K`!!0X@(```H,`P3C`0!`XS?]_^L-$*#A&`,$XP$`0./V^__K
M`!!0X@\```I0`@3C`0!`XR[]_^M8,)_E`""3Y00PG>4"(#/@`#"@XQ```!H\
M$P3C`1!`XZ0"!.,!`$#C#-"-XC!`O>@A_?_J#1"@X2@#!.,!`$#CX/O_ZP`0
M4.+L__\*P`($XP$`0.,8_?_KZ/__ZM'Z_^L$_P(`!.`MY<`"!.,!`$#C#-!-
MXE0PG^4-$*#A`#"3Y00PC>4`,*#CSOO_ZP``4.,%```*``#0Y0``4.,P`%`3
M`0"@`P``H!,!`"#B'#"?Y0`@D^4$,)WE`B`SX``PH.,!```:#-"-X@3PG>2U
M^O_K!/\"`!!`+>EJ^O_KD/K_ZP``4.,``)`5$("]Z'!`+>D`4*#A`#&?Y1C0
M3>)``P3C`0!`XQ`0C>(`,)/E%#"-Y0`PH..K^__K`$!0X@X```H`,-3E``!3
MXPL```H%$*#AA/K_ZP``4.,3```*N#"?Y0`@D^44,)WE`B`SX``PH.,H```:
M&-"-XG"`O>B8,)_E`""3Y10PG>4"(#/@`#"@XP40H`%``P0#`0!``QT``!H8
MT(WB<$"]Z,O\_^H%`*#A6OK_ZP!@H.$$`*#A5_K_ZP``AN`"`(#B>_K_ZP$0
MH.,`(.#C;#($XP$P0.,`4(WE&`"-Z7`R!.,!,$#C`$"@X9CZ_^L@,)_E`""3
MY10PG>4"(#/@`#"@XP00H`%``P0#`0!``^'__PIJ^O_K!/\"`/!/+>D`8*#A
MU#6?Y>S03>+0)9_E@%"-X@S@@^(`()+EY""-Y0`@H.,D0(/B!P"3Z`<`A>B8
MP(WB#P"^Z(QPC>(/`*SH`P">Z`,`C.@'`)3H!P"'Z!@0C>)0`@3C`0!`XUC[
M_^L`0%#B`@``"@`PU.4``%/C#@$`&@+Z_^LH^O_K``!0XW8```H`@)#E``!8
MXW,```H(`*#A&/K_ZX``H.$!`(#B//K_ZP`PV.4`0*#A`'"@X0``4^,+```*
M6),$XP&00.,$`*#A`#"-Y0$0H.,),*#A`"#@XP)`A.)5^O_K`3#XY0``4^/U
M__\:#`,$XP$`0..8@(WB`@``Z@0`N.4``%#C#0``"A@0C>(M^__K`$!0XOC_
M_PH`,-3E``!3X_7__PI:^__K``!0X_+__PH$`*#A#_K_ZP!`4.(,```:!$"5
MY```5.,)```*`##4Y0``4^/%```*!`"@X4S[_^L``%#C\?__&@1`E>0``%3C
M]?__&@0`H.%X@@3C`8!`X][Y_^L`H*#A!P"@X=OY_^L`H(K@`:N*X@2@BN(*
M`*#A_?G_ZP$0H.,`D*#A`"#@XPQPC>5L,P3C`3!`XP!`C>4(,(WE8#,$XP$P
M0.,$@(WE&/K_ZP<=H.,)`*#A>?G_ZP$`<.,#```:+?K_ZP`@D.41`%+CHP``
M&A@0C>()`*#A]/G_ZP!04.(J```*,`$`XP,`0.,`,);EL",$XP$@0.,!$*#C
M``"0Y0"0C>7@^?_K`'"@XZPSG^4`()/EY#"=Y0(@,^``,*#CY```&@<`H.'L
MT(WB\(^]Z,;Y_^L`@%#BA```&@0`E^0``%#C"0``"A@0C>+3^O_K`#!0XOC_
M_PH`,-/E``!3X_+__QH$`)?D``!0X_7__QH-`*#C4(,$XP&`0..\^?_K4S"@
MXP!`H.$`<*#A@/__ZB@PG>4/.@/B`0E3X]#__QHP0)WE;?G_ZP``5.',__\:
M*#"=Y5,PZ.<'#5/CR/__&@H`H.&J^?_K&!"-X@!PH.$$!`3C`0!`X[#Z_^L`
M$%#B=```"@``EN7+_/_K`*!0XG````H*`*#A=OG_ZP!`H.$#`%#C#```F@0`
M0.(,%`3C`1!`XP``BN#1^?_K``!0XP4``!H$`%3CDP``"@1`BN`%,%3E+P!3
MXX\```H8$(WBP`($XP$`0..4^O_K``!0XP,```H`,-#E,`!3XP``4Q,$```:
M"@"@X0`0H.-H^?_K`$!0XE$``!H\$P3C`1!`X\`"!.,!`$#CP?O_Z^1D!.,!
M8$#CD?G_ZP$0H.,(`(WE!("-Y0<`H.$`D(WE+#0$XP$P0.,,8(WE`"#@XSRD
M!.,!H$#CD?G_ZP\``.JJ^?_K`#"0Y1$`4^,1```:?_G_ZP%0A>(`P*#A"C"@
MX00@H.$!$*#C!P"@X1!@C>4,4(WE`!&-Z0"0C>6`^?_K!QV@XP<`H.'A^/_K
M`$"@X0$`<./I__\*"0"@X0_Y_^L'$*#A4`($XP$`0..5^__K!P"@X9_^_^MP
M___J`T"@X3[__^H@^?_K@`"@X0$`@.(&___J,`$`XP,`0.,`,);E`1"@XP0@
MC>5T(P3C`2!`XP"0C>4``)#E0/G_ZU[__^J,_O_K*#&?Y0`@D^7D,)WE`B`S
MX``PH.-#```:!`"@X>S0C>+P3[WH)?G_Z@"@EN6,___JW_K_ZP!@H.$`H%'B
MJ?__N@H@4.(`L*#C`##*X@0`H.$`L(WE'_G_ZP8@H..P$(WB!`"@X=_X_^NP
M()WE0SR@XT$S1.,#`%+AFO__&K0KW>%(-03C`P!2X9;__QHR(%;BN%"-X@`P
MRN($`*#A`+"-Y0SY_^L%$*#A!`"@X2@@H./,^/_K!P"@X0A0C>4<-`3C`3!`
MXP2`C>4`D(WE`"#@X^04!.,!$$#C#!"-Y0$0H./@L,WE)?G_ZZG__^H$0);E
M``!4XVS__PH$`*#AT?C_ZP,`4.-H__^:!`!`XA04!.,!$$#C``"$X"WY_^L`
M`%#C!*"@`6#__^KP^/_K2(,!``3_`@!P0"WI<$\=[C0BG^4(T$WB,#*?Y0`@
MDN4$((WE`""@XPT0H.&D`@3C`0!`XP,PG^<#4)3G:##5Y6DPQ>7F^?_K``!0
MXP(```H`,-#E,0!3XV,```K;_/_K[#&?Y0,PG^<#4)3G!0"@X0,PH.,!(*#C
M4!0$XP$00.-X^/_K`%!0X@P```K$,9_E$""5Y0,PG^<`$)+E5"0$XP$@0.,#
M`)3G=/C_ZQ`PE>4`$)/E"#"1Y0$%$^-6```:E!&?Y0,PH.,!(*#C`1"?YP$`
ME.=<%`3C`1!`XV'X_^L`8%#B"P``"@T0H.%<`@3C`0!`X[KY_^L`(%#B/@``
M"E@QG^40$);E`S"?YP`0D>4#`)3G6?C_ZSQ1`.,#4$#C/#&?Y0$@H.-@%`3C
M`1!`XP,PG^<#8)3G!@"@X3?X_^MX)`3C`2!`XP`0H.$&`*#A2OC_ZPPQG^4`
M(*#C#1"@X5`"!.,!`$#C`S"?YP,PE.=I(,/EFOG_ZP!`H.$``%#C"`"%Y0\`
M``H'':#C!`"@X1/X_^L!((#B`#"@X1$`4.,!`%(3(@``BIPPG^4`()/E!#"=
MY0(@,^``,*#C&P``&@C0C>)P@+WH!`"5Y1+^_^L`0*#A``!0XP@`A>7I__\:
M@`0$XP$`0..*^/_K`3#0Y0``4^.<__\*E___ZCQ1`.,#4$#C$""6Y00PE>4`
M`)+E`!"3Y6_Z_^O`___J2#"?Y0,PG^<#`)3G7/C_ZZ/__^IC^/_K!!"5Y:0$
M!.,!`$#C!""@X0`0D>5R^/_K!/\"`-S2`0"LT@$`?-(!`$32`0`(T@$`X-$!
M`*C1`0#PT`$`,$`MZ0!0H.'H,)_E#-!-X@`PD^4$,(WE`#"@XP7\_^LO$*#C
M`$"@X?OW_^L``%#C`4"`$@0`H.$Y^/_K#1"@X0!`H.'``@3C`0!`XTCY_^L`
M,%#B"@``"@`PT^4P`%/C``!3$P$PH`,`,*`3`3`CX@``5>,`,*`#`3`#$@``
M4^,'```:;#"?Y0`@D^4$,)WE`B`SX``PH.,5```:#-"-XC"`O>@`,-7E``!3
MX_3__PH$(*#C!`"@X6P3!.,!$$#C2OC_ZP``4./M__\:)#"?Y0`@D^4$,)WE
M`B`SX``PH.,#```:!0"@X0S0C>(P0+WH<_G_ZA;X_^L$_P(``````/!/+>D`
M$*#AS#R?Y:??3>)``(#B$""-XH!@@>(`,)/EE#*-Y0`PH.,`4*#C$!`0Z010
M@N4,4(+E$"""XC1/O^800`+E+#2@X0SDH.'_/`/B"`"`XBP\@^'_Z`[B##R#
MX08`4.$.,(/A"#`"Y>[__QJ&/XWB"#"-Y8@PG>48`(WB'*"=Y0P0C>4#$*#A
M>("=Y7P@G>48L)WE@'"=Y81@G>6,P)WE$%"=Y11`G>4$H(WE`0``Z@FPH.$$
M,(WE`3"@X3S@D.4X$)#E`*"@XPB0L.5TH(#E"1`AX`@0(>`'@*#A`W"@X00P
MD.4%$"'@"U"@X0/@+N`"X"[@!B"@X03@+N`,8*#AH<^@X0$0D>".P(SA!$"=
MY0P0@>$(P)WE<!"`Y0``7.$*P*#AX?__&@P0G>40()WEN&"=Y0`4D>@(D)'E
M##"1Y2``D>6J3:#A*5&@X1"`D>4#7X7AF3D'XX(Z1>,8L)'EC$*$X0,@DN``
M()+@BD*$X0)`E.`+("C@"2`"X`E?A>$+("+@!0`HX`)`E.`8()WE"@``X`,@
MDN`(`"#@"R"2X`#@DN`J`:#A#`^`X2`@G>4*#X#AY.V.X`#`)>`#()+@!,`,
MX`@@DN`%P"S@9$&@X0S`DN`H()WE[LV,X`,@DN`%()+@!%`@X`Y0!>!NX:#A
M`%`EX`50DN`P()WE[%V%X`,@DN``()+@#@`DX`P``.!LP:#A!``@X```DN`X
M()WEY0V`X`,@DN`$()+@#$`NX`5`!.!E4:#A#D`DX`1`DN!`()WEX$V$X`,@
MDN`.()+@!>`LX`#@#N!@`:#A#.`NX`[@DN!(()WEY.V.X`,@DN`,()+@`,`E
MX`3`#.!D0:#A!<`LX`S`DN!0()WE[LV,X`,@DN`%()+@!%`@X`Y0!>!NX:#A
M`%`EX`50DN!8()WE[%V%X`,@DN``()+@#@`DX`P``.!LP:#A!``@X```DN!@
M()WEY0V`X`,@DN`$()+@#$`NX`5`!.!E4:#A#D`DX`1`DN!H()WEX$V$X`,@
MDN`.()+@!>`LX`#@#N!@`:#A#.`NX`[@DN!P()WEY.V.X`,@DN`,()+@`,`E
MX`3`#.!D0:#A!<`LX`S`DN!X()WE[LV,X`,@DN`%()+@!%`@X`Y0!>!NX:#A
M`%`EX`50DN"`()WE[%V%X`,@DN``()+@#@`DX`P``.!LP:#A!``@X``@DN"(
M`)WEY2V"X`,`D.`$`)#@#$`NX`5`!.!E4:#A#D`DX`1`D."0`)WEXDV$X`,`
MD.`.`)#@!>`LX`+@#N!B(:#A#.`NX`[@D."8`)WEY.V.X`,`D.`,`)#@`L`E
MX`3`#.!D0:#A!<`LX`S`D."@`)WE[LV,X`,`D.`%`)#@!%`BX`Y0!>!NX:#A
M`E`EX`4`D."H4)WE[`V`X`,PE>"P4)WE`C"3X`X@).`,(`+@;,&@X00@(N`"
M,)/@X"V#X*$[#N/9/D;C`U"5X`10E>`,0"[@`$`DX&`!H.$$0)7@`U"6X`Y0
ME>#`8)WE`.`LX.)-A.`"X"[@8B&@X0[@E>`#4);@#%"5X,A@G>4"P"#@Y.V.
MX`3`+.!D0:#A#,"5X`-0EN``4)7@T&"=Y00`(N#NS8S@#@`@X&[AH.$``)7@
M`U"6X`)0E>#88)WE#B`DX.P-@.`,("+@;,&@X0(@E>`#4);@!%"5X.!@G>4,
M0"[@X"V"X`!`).!@`:#A!$"5X`-@EN`.X);@`%`LX.A@G>7B383@`E`EX&(A
MH.$%4)[@\'"=Y0-@EN`"X"#@#,"6X`3@+N!D8:#AY%V%X`[@G.`#<)?@``"7
MX`;`(N#X<)WE94&@X07`+.#E[8[@#,"0X`!1G>4#<)?@!``FX`X`(.`"()?@
M[LV,X``@DN!NX:#A`U"5X`9PE>`.`"3@"&&=Y0P`(.#L+8+@``"7X&S!H.$#
M8);@!&"6X!!1G>4,0"[@X@V`X`)`).!B(:#A!$"6X`-0E>`889WE#E"5X`+@
M+.#@383@`.`NX&`!H.$.X)7@`U"6X`Q0E>`@89WE`,`BX.3MCN`$P"S@9$&@
MX0S`E>`#4);@`E"5X"AAG>4$("#@[LV,X`X@(N!NX:#A`B"5X`-@EN```);@
M#E`DX#!AG>4,4"7@["V"X`50D.!LP:#A`P"6X`0`D.`X89WE#$`NX.)=A>`"
M0"3@8B&@X01`D.`#`);@0'&=Y0X`D.`"X"S@Y4V$X`7@+N`.8)#@9>&@X0,`
ME^#D;8;@#`"0X`[`(N`$P"S@4'&=Y0P`D.!DP:#A2$&=Y>8-@.!F4:#A`S"4
MX`5`C.$",)/@#"`NX`8@(N``0`3@`C"3X.`M@^#</`OC&S](XV`!H.$#8)?@
M6'&=Y0[@EN`%8`S@!D"$X0!@!>`$0)[@`."%X0-PE^`"X`[@#,"7X`;@CN$,
MX)[@8,&=Y>)-A.!B(:#A`\"<X`)@`.`%P)S@`E"`X6AQG>4$4`7@Y.V.X`90
MA>%D0:#A#,"5X`1@@N$#4)?@[LV,X'!QG>4`4)7@#F`&X&X!H.$$X`+@#F"&
MX05@EN`#X)?@`%"$X0+@GN`,4`7@["V&X`!@!.!LP:#A!E"%X8!QG>4.4)7@
M>.&=Y0Q@`.#B787@`^">X`3@GN`,0(#A`D`$X&(AH.$&0(3A`F`,X`Y`E.`#
MX)?@`.">X.4-A.`"0(SAB'&=Y05`!.!E4:#A!D"$X05@`N`.0)3@!>""X0-P
ME^``X`[@#,"7X`;@CN$,X)[@D,&=Y>!-A.!@`:#A`\"<X`!@!>`"()S@`,"%
MX9AQG>4$P`S@!L",X>3MCN`"P)S@9$&@X0,@E^`$8`#@!2"2X`10@.&@<9WE
M#E`%X.[-C.`&4(7A;N&@X0)0E>`#()?@#F`$X``@DN#L#87@#E"$X;!QG>4,
M4`7@;,&@X090A>$,8`[@`B"5X*A1G>7@+8+@`U"5X`1`E>`,4([A`%`%X&`!
MH.$&4(7A`&`,X`1`E>``4(SA`W"7X`)0!>#B383@!E"%X6(AH.$.X)?@N'&=
MY0[@E>`"4(#A`F``X`-PE^`$4`7@!E"%X0S`E^`,P)7@P%&=Y>3MCN!D0:#A
M`U"5X`1@`N```)7@!%""X0Y0!>#NS8S@!E"%X6[AH.'(<9WE``"5X`Y0A.$.
M8`3@`W"7X`Q0!>#L#8#@`B"7X`90A>'0<9WE;,&@X0)0E>#@+87@#%".X0Q@
M#N`#<)?@`%`%X`1`E^`&4(7A8`&@X010E>``8*#CXDV%X-A1G>7@<9WE`U"5
MX`1@@>4.X)7@`%",X0)0!>`,8('E%&"!Y6(AH.$<8('E`&`,X`90A>$"8`#@
M#N"5X`-0E^`,4)7@`L"`X>AQG>4$P`S@Y.V.X`;`C.%D0:#A!<"<X`-PE^`$
M,(+A!%`"X`XP`^#NS8S@``"7X`4P@^'P89WE`#"3X&[AH.'L#8/@UC$,XV(Z
M3.,#4);@^&&=Y0)0E>`.("3@#"`BX&S!H.$"()7@`U"6X`10E>``8IWE#$`N
MX.`M@N``0"3@8`&@X01`E>`#4);@#E"5X`ABG>4`X"S@XDV$X`+@+N!B(:#A
M#N"5X`-0EN`,4)7@$&*=Y0+`(.#D[8[@!,`LX&1!H.$,P)7@`U"6X`!0E>`8
M8IWE!``BX.[-C.`.`"#@;N&@X0``E>`#4);@`E"5X"!BG>4.("3@[`V`X`P@
M(N!LP:#A`B"5X`-0EN`$4)7@*&*=Y0Q`+N#@+8+@`$`DX&`!H.$$0)7@`U"6
MX`Y0E>`P8IWE`.`LX.)-A.`"X"[@8B&@X0[@E>`#4);@#%"5X#ABG>4"P"#@
MY.V.X`3`+.!D0:#A#,"5X`-0EN``4)7@0&*=Y00`(N#NS8S@#@`@X&[AH.$`
M`)7@`U"6X`)0E>!(8IWE#B`DX.P-@.`,("+@;,&@X0(@E>`#4);@!%"5X%!B
MG>4,0"[@X"V"X`!`).!@`:#A!$"5X`-0EN`.4)7@6&*=Y0#@+.#B383@`N`N
MX&(AH.$.X)7@`U"6X`Q0E>!@8IWE`L`@X.3MCN`$P"S@9$&@X0S`E>`#4);@
M`%"5X&ABG>4$`"+@[LV,X`X`(.!NX:#A``"5X`-0EN`"4)7@<&*=Y0X@).#L
M#8#@#"`BX&S!H.$"()7@`U"6X`10E>!X8IWE#$`NX.`M@N``0"3@8`&@X01`
ME>`#8);@#N"6X`!0+."`8IWE`E`EX.)-A.`%4)[@8B&@X0-@EN"(XIWE#,"6
MX`)@(.#D787@!&`FX&1!H.$&P)S@`S">X`HPD^#ES8S@`#"3X`0`(N`%`"#@
M98&(X``PD^``8*#C[#V#X``P@>4@,)'E"9"<X!"`@>4+`)3@")"!Y0,@DN`8
M`('E)#"?Y2`@@>4D8('E`""3Y90RG>4"(#/@`#"@XP$``!JGWXWB\(^]Z-WT
M_^L$_P(`$$`MZ8``H./6]/_K#WN?[0`@H.-X((#E`'N`[0U[G^T">X#M#7N?
M[01[@.T->Y_M!GN`[0U[G^T(>X#M#7N?[0I[@.T,>X#M$("]Z`#P(.,!(T5G
M`````(FKS>\`````_MRZF`````!V5#(0`````/#ATL,```````````````#P
M1RWI`F"@X0`PH.,H<)#E`%"@X2S@D.4!0*#A,""0Y8;!A^`T$)#E!P!<X<8/
MH.$.X-/@`0``*@$@DN(`$*'B+#"%Y:8^H.&`,8/A.("%X@(PD^`HP(7EH!ZA
MX'@`E>4P,(7E``!0XS00A>4@```:/P!6XR\``-I`D$;B*6.@X0%PAN('<X3@
M!!"@X0@PH.%`0(3B`."1Y1`0@>(,P!'E$#"#X@@`$>4$(!'E!`!1X1#@`^4,
MP`/E"``#Y00@`^7S__\:`4"@X04`H.%S_/_K!P!4X>O__QH&8TG@!B"@X0<0
MH.$(`*#A7?3_ZWA@A>7PA[WH0'!@X@00H.$&`%?A``"(X`9PH*$'(*#A5/3_
MZW@PE>4#,(?@>#"%Y4``4^/PA[T8!0"@X0=@1N`'0(3@6OS_Z\W__^H$<*#A
MYO__ZO!!+>DX<('B`4"@X2@PD>4`4*#A,&"1Y7\0X.,SC[_FTS'EYS9OO^8!
M((/B.`!2XP(`A^`#$,?G/```VD`@8N(`$*#C!O3_ZP0`H.%#_/_K!P"@X3@@
MH.,`$*#C`/3_ZP0`H.%P8(3E=("$Y3O\_^L#,-3E`##%Y00`H.&R,-3A`3#%
MY0`PE.4C-*#A`C#%Y0`PE.4#,,7E"S#4Y00PQ>6Z,-3A!3#%Y0@PE.4C-*#A
M!C#%Y0@PE.4',,7E$S#4Y0@PQ>6R,=3A"3#%Y1`PE.4C-*#A"C#%Y1`PE.4+
M,,7E&S#4Y0PPQ>6Z,=3A#3#%Y1@PE.4C-*#A#C#%Y1@PE.4/,,7E(S#4Y1`P
MQ>6R,M3A$3#%Y2`PE.4C-*#A$C#%Y2`PE.43,,7E\$&]Z-OS_^HX(&+B`!"@
MX\GS_^O'___J"#"?Y0,PC^``,)/E*O3_ZLB_`0`(0"WI"("]Z`$``@`]````
M0`````L```!`````$````$`````F````0````#4```!``````P```$`````&
M````0````!0```!`````#@```$`````-````0````"4```!`````$@```$``
M```H````0`````(```!`````&````$`````)````0`````H```!`````````
M```````E<R\E<P```"]P<F]C+W-E;&8O97AE``!$>6YA3&]A9&5R.CIB;V]T
M7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`````+W!R;V,O)6DO
M)7,`97AE`"X```!005)?5$5-4`````!005)?4%)/1TY!344`````.@```"5S
M)7,E<P``+P```%!%4DPU3$E"`````%!%4DQ,24(`4$523#5/4%0`````4$52
M3$E/``!005)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,14%.````
M4$%27T1%0E5'````4$%27T-!0TA%````4$%27T=,3T)!3%]$14)51P````!0
M05)?1TQ/0D%,7U1-4$1)4@```%!!4E]435!$25(``%!!4E]'3$]"04Q?5$5-
M4`!005)?1TQ/0D%,7T-,14%.`````#$```!,1%],24)205)97U!!5$@`4UE3
M5$5-```E,#)X`````"5S)7,E<R5S`````'!A<BT`````)7,Z(&-R96%T:6]N
M(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI
M"@``)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE
M87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@``4$%4
M2`````!P87)L`````"YP87(`````)7,E<V-A8VAE+25S)7,``"5S)7-T96UP
M+25U)7,````E<R5S=&5M<"TE=2TE=25S`````!@```!P97)L`````#````!0
M05(Z.E!A8VME<CHZ5D524TE/3@`````Q+C`U-P```%5N86)L92!T;R!C<F5A
M=&4@8V%C:&4@9&ER96-T;W)Y`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E
M(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`````
M+64``"TM``!54T52`````%5315).04U%`````%1%35!$25(`5$U0`"]T;7``
M````979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG
M"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E
M(%]?<&%R7W!L.PIM>2`H)%!!4E]-04=)0RP@)$9)3$5?;V9F<V5T7W-I>F4L
M("1C86-H95]N86UE7W-I>F4I.PI"14=)3B!["B1005)?34%'24,@/2`B7&Y0
M05(N<&U<;B(["B1&24Q%7V]F9G-E=%]S:7IE(#T@-#L@("`C('!A8VLH(DXB
M*0HD8V%C:&5?;F%M95]S:7IE(#T@-#`["B102UI)4%]-04=)0R`](")02UPP
M,#-<,#`T(CL*?0IS=6(@9FEN9%]P87)?;6%G:6,*>PIM>2`H)&9H*2`]($!?
M.PIM>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@)&)U9CL*;7D@)'-I
M>F4@/2`M<R`D9F@["FUY("1P;W,@/2`H)'-I>F4M,2D@+2`H)'-I>F4M,2D@
M)2`D8VAU;FM?<VEZ93L@("`@("`C($Y/5$4Z("1P;W,@:7,@82!M=6QT:7!L
M92!O9B`D8VAU;FM?<VEZ90IW:&EL92`H)'!O<R`^/2`P*2!["G-E96L@)&9H
M+"`D<&]S+"`P.PIR96%D("1F:"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG
M=&@H)%!!4E]-04=)0RD["FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!
M4E]-04=)0RDI(#X](#`I('L*<F5T=7)N("1P;W,@*R`D:3L*?0HD<&]S("T]
M("1C:'5N:U]S:7IE.PI]"G)E='5R;B`M,3L*?0IM>2`H)'!A<E]T96UP+"`D
M<')O9VYA;64L($!T;7!F:6QE+"`E36]D=6QE0V%C:&4I.PI%3D0@>R!I9B`H
M)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER
M92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P
M9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T
M<RAQ<5M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(ETI.PI&:6QE.CI&
M:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@
M?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T
M96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE
M.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ
M0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L
M"E5.3$E.2R`]/B`P+`HI.PIM>2`D9FEL96YA;64@/2`D=&UP+3YF:6QE;F%M
M93L*<')I;G0@)'1M<"`\/"(N+BXB.PIX/3$[('=H:6QE(%L@7"1X("UL="`Q
M,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T
M96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q
M8`ID;VYE"G)M("<D9FEL96YA;64G"BXN+@IC;&]S92`D=&UP.PIC:&UO9"`P
M-S`P+"`D9FEL96YA;64["FUY("1C;60@/2`B)&9I;&5N86UE(#XO9&5V+VYU
M;&P@,CXF,2`F(CL*<WES=&5M*"1C;60I.PIO=71S*'%Q6U-P87=N960@8F%C
M:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@)&9I;&5N86UE
M72D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D
M969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI
M=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)7-Y
M<R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z
M("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\
M8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@
M/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA
M;64H*3L*;W5T<RAQ<5M<)'!R;V=N86UE(#T@(B1P<F]G;F%M92)=*3L*7W-E
M=%]P87)?=&5M<"@I.PIO=71S*'%Q6UPD14Y6>U!!4E]414U0?2`]("(D14Y6
M>U!!4E]414U0?2)=*3L*;7D@*"1S=&%R=%]P;W,L("1S=&%R=%]O9E]&24Q%
M7W-E8W1I;VXI.PI-04=)0SH@>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U
M8B![?3L*=6YL97-S("AO<&5N(%]&2"P@)SPZ<F%W)RP@)'!R;V=N86UE*2![
M"F]U=',H<7%;0V%N)W0@<F5A9"!F<F]M(&9I;&4@(B1P<F]G;F%M92)=*3L@
M(",@9&]N)W0@=7-E("0A(&AE<F4@87,@:70@<F5Q=6ER97,@17)R;F\N<&T*
M;&%S="!-04=)0SL*?0IM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H
M*E]&2"D["FEF("@D;6%G:6-?<&]S(#P@,"D@>PIO=71S*'%Q6T-A;B=T(&9I
M;F0@;6%G:6,@<W1R:6YG("(D4$%27TU!1TE#(B!I;B!F:6QE("(D<')O9VYA
M;64B72D["FQA<W0@34%'24,["GT*;W5T<R@B1F]U;F0@4$%2(&UA9VEC(&%T
M('!O<VET:6]N("1M86=I8U]P;W,B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@
M+2`D1DE,15]O9F9S971?<VEZ92`M(&QE;F=T:"@B7#!#04-(12(I+"`P.PIR
M96%D(%]&2"P@)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&YE
M(")<,$-!0TA%(B`F)B`D8G5F(&YE(")<,$-,14%.(BD@>PIO=71S*").;R!C
M86-H92!M87)K97(@9F]U;F0B*3L*;&%S="!-04=)0SL*?0IO=71S*'%Q6T-A
M8VAE(&UA<FME<B`B)&)U9B(@9F]U;F1=*3L*<V5E:R!?1D@L("1M86=I8U]P
M;W,@+2`D1DE,15]O9F9S971?<VEZ92P@,#L*<F5A9"!?1D@L("1B=68L("1&
M24Q%7V]F9G-E=%]S:7IE.PIM>2`D;V9F<V5T(#T@=6YP86-K*").(BP@)&)U
M9BD["F]U=',H(D]F9G-E="!F<F]M('-T87)T(&]F($9)3$5S(&ES("1O9F9S
M970B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ
M92`M("1O9F9S970L(#`["B1S=&%R=%]O9E]&24Q%7W-E8W1I;VX@/2!T96QL
M(%]&2#L*;7D@)7)E<75I<F5?;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(R!R96%D('1H92!F:7)S="`B1DE,
M12(*=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T
M.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL
M;F%M92`]("1B=68["F]U=',H<7%;56YP86-K:6YG($9)3$4@(B1F=6QL;F%M
M92(N+BY=*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=
M>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@
M/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@
M)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII
M9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA
M;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1C<F,D97AT(BP@
M)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE
M?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA
M;65](#T@)&9U;&QN86UE.PI]"F5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_
M<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*;7D@)&9I
M;&5N86UE(#T@7W-A=F5?87,H(B1B87-E;F%M921E>'0B+"`D8G5F+"`P-S4U
M*3L*;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["GT*96QS92!["B1-;V1U
M;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C
M<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PHD<F5Q=6ER95]L:7-T>R1F=6QL
M;F%M97TK*SL*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@
M*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E
M9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`]("1-;V1U;&5#86-H
M97LD;6]D=6QE?3L*<F5T=7)N('5N;&5S<R`D:6YF;SL*9&5L971E("1R97%U
M:7)E7VQI<W1[)&UO9'5L97T["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D
M:6YF;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE
M9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T
M;7!F:6QE(&]R(&1I92`B0V%N)W0@8W)E871E('1E;7`@9FEL93H@)"$B.PHD
M9F@M/F)I;FUO9&4H*3L*)&9H+3YP<FEN="@D:6YF;RT^>V)U9GTI.PHD9F@M
M/G-E96LH,"P@,"D["G)E='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M
M92`](%]S879E7V%S*"(D:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI
M.PHD:6YF;RT^>V9I;&5](#T@)&9I;&5N86UE.PIO<&5N(&UY("1F:"P@)SPZ
M<F%W)RP@)&9I;&5N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL96YA
M;64B.B`D(5T["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A
M:6QE9#H@8V%N)W0@9FEN9"!M;V1U;&4@)&UO9'5L92$B.PI]+"!`24Y#*3L*
M<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E
M($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(
M96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW
M:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T
M*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@
M/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2![
M"G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL
M97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E
M;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*:68@*"1B=68@;F4@
M)%!+6DE07TU!1TE#*2!["F]U=',H<7%;3F\@>FEP(&9O=6YD(&%F=&5R($9)
M3$4@<V5C=&EO;B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,@
M.PI]"B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L@("`@("`@("`@("`@
M("`@(R!S=&%R="!O9B!Z:7`*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D
M8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E("1%3E9[4$%2
M7T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R
M:71Y('!R;V)L96TI"FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@
M)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q
M=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T
M86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!
M4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8[
M"B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@
M(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE
M("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH
M+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I
M;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*
M?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*
M?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@
M97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("="
M)RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD
M<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L
M("(^/B(L("0R(&]R(&1I92!Q<5M#86XG="!O<&5N(&QO9R!F:6QE("(D,B(Z
M("0A73L*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#([
M"GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI
M('L*9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I
M<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`
M05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI
M=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U
M="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP
M.PIR97%U:7)E($1I9V5S=#HZ4TA!.PI]"FUY("1P87(@/2!S:&EF="A`05)'
M5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D9F@L
M("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(&9I;F0@<&%R(&9I;&4@
M(B1P87(B.B`D(5T["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!
M<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H
M)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@
M<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!A<B)=.PI]"FUY("5M
M971A7W!A<B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^
M8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O
M;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK
M*3H@*"XK*20O;6<["GT*?3L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY
M("1P:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@<F5A9"!P87(@
M9FEL92`B)'!A<B(Z("0A73L*;7D@)&)U9CL*<F5A9"`D<&@L("1B=68L(#0[
M"F1I92!Q<5LB)'!A<B(@:7,@;F]T(&$@<&%R(&9I;&5=('5N;&5S<R`D8G5F
M(&5Q("102UI)4%]-04=)0SL*8VQO<V4@)'!H.PI]"D-R96%T95!A=&@H)&]U
M="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ
M3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?4D174B@I('P@24\Z.D9I;&4Z.D]?
M5%)53D,H*2P*,#<W-RP**2!O<B!D:64@<7%;0V%N)W0@8W)E871E(&9I;&4@
M(B1O=70B.B`D(5T["B1F:"T^8FEN;6]D92@I.PIS965K(%]&2"P@,"P@,#L*
M;7D@)&QO861E<CL*:68@*&1E9FEN960@)'-T87)T7V]F7T9)3$5?<V5C=&EO
M;BD@>PIR96%D(%]&2"P@)&QO861E<BP@)'-T87)T7V]F7T9)3$5?<V5C=&EO
M;CL*?2!E;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*)&QO861E<B`](#Q?1D@^
M.PI]"FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>
M*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I
M<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I
M.PI]"B1F:"T^<')I;G0H)&QO861E<BD*;W(@9&EE('%Q6T5R<F]R('=R:71I
M;F<@;&]A9&5R('1O("(D;W5T(CH@)"%=.PII9B`H)&)U;F1L92D@>PIR97%U
M:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H
M*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G
M<F5P('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@
M;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@
M;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIS?"\K
M?"]\9RP@<WPO)'Q\(&9O<F5A8V@@0&EN8SL*;7D@)69I;&5S.PHD9FEL97-[
M)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L
M=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E
M>'1].R`@("`@("`@(",@6%A8(&QI8E]E>'0@=G,@9&QE>'0@/PIM>2`E=W)I
M='1E;CL*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)69I;&5S*2!["FUY
M("@D9FEL92P@)&YA;64I.PII9B`H9&5F:6YE9"AM>2`D9F,@/2`D4$%2.CI(
M96%V>3HZ1G5L;$-A8VAE>R1K97E]*2D@>PHH)&9I;&4L("1N86UE*2`]("@D
M:V5Y+"`D9F,I.PI]"F5L<V4@>PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*
M:68@*"1K97D@/7X@;7Q>7%$D9&ER7$4O*"XJ*21\:2D@>PHH)&9I;&4L("1N
M86UE*2`]("@D:V5Y+"`D,2D["FQA<W0["GT*:68@*"1K97D@/7X@;7Q>+VQO
M861E<B];7B]=*R\H+BHI)'PI('L*:68@*&UY("1R968@/2`D36]D=6QE0V%C
M:&5[)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*
M?0II9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER
M+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@
M)&YA;64["FYE>'0@:68@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E
M9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O:3L*;W5T
M<RAS<')I;G1F*'%Q6U!A8VMI;F<@1DE,12`B)7,B+BXN72P@<F5F("1F:6QE
M(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE*2D["FUY("1C;VYT96YT.PII9B`H
M<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E
M('L*;&]C86P@)"\@/2!U;F1E9CL*;W!E;B!M>2`D=&@L("<\.G)A=R<L("1F
M:6QE(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL92(Z("0A73L*)&-O;G1E
M;G0@/2`\)'1H/CL*8VQO<V4@)'1H.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M
M/F%P<&QY*%PD8V]N=&5N="P@(CQE;6)E9&1E9#XO)&YA;64B*0II9B`A)$5.
M5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD
M+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C
M;VYT96YT+"`D9FEL92P@)&YA;64I.PI]"B1F:"T^<')I;G0H(D9)3$4B+`IP
M86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI+`IS<')I;G1F*"(E,#AX+R5S
M(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M
M92DL"G!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2P*)&-O;G1E;G0I"F]R
M(&1I92!Q<5M%<G)O<B!W<FET:6YG(&5M8F5D9&5D($9)3$4@=&\@(B1O=70B
M.B`D(5T["F]U=',H<7%;5W)I='1E;B!A<R`B)&YA;64B72D["GT*?0II9B`H
M)'II<"D@>PHD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(#T]($%R8VAI
M=F4Z.EII<#HZ05I?3TL*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@>FEP('!A
M<G0@;V8@(B1O=70B73L*?0II9B`H)&UE=&%?<&%R>V-L96%N?2D@>PHD9F@M
M/G!R:6YT*")<,$-,14%.(BD["GT*96QS92!["FEF("@A9&5F:6YE9"`D8V%C
M:&5?;F%M92D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*<V5E
M:R`D9F@L(#`L(#`["B1C='@M/F%D9&9I;&4H)&9H*3L*<V5E:R`D9F@L(#`L
M(#(["B1C86-H95]N86UE(#T@)&-T>"T^:&5X9&EG97-T.PI]"B1C86-H95]N
M86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`D8V%C:&5?;F%M95]S:7IE
M.PHD8V%C:&5?;F%M92`N/2`B7#`B('@@*"1C86-H95]N86UE7W-I>F4@+2!L
M96YG=&@@)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*"1C86-H95]N86UE+`HB
M7#!#04-(12(I.PI]"FUY("1O9F9S970@/2`D9F@M/G1E;&P@+2!L96YG=&@H
M)&QO861E<BD["B1F:"T^<')I;G0H<&%C:R@G3B<L("1O9F9S970I+`HD4$%2
M7TU!1TE#*3L*)&9H+3YC;&]S92!O<B!D:64@<7%;17)R;W(@=W)I=&EN9R!T
M<F%I;&5R(&]F("(D;W5T(CH@)"%=.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET
M.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R
M;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA
M;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI
M=F4Z.EII<#L*?0IM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@;VX@
M86X@24\Z.DAA;F1L90HD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O
M<B!D:64@<7%;9F1O<&5N*"D@9F%I;&5D.B`D(5T["D%R8VAI=F4Z.EII<#HZ
M<V5T0VAU;FM3:7IE*"US(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E.CI::7`M
M/FYE=SL**"1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M
M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@
M<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!R;V=N86UE(ET["D%R8VAI=F4Z.EII
M<#HZ<V5T0VAU;FM3:7IE*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C
M:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PIO
M=71S*")%>'1R86-T:6YG('II<"XN+B(I.PII9B`H9&5F:6YE9"`D14Y6>U!!
M4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R
M96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D
M;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E
M<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>
M"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD
M0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@
M)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E
M8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF
M("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S
M<V5D4VEZ92@I*2!["F]U=',H<7%;4VMI<'!I;F<@(B1M96UB97)?;F%M92(@
M<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B72D["GT@
M96QS92!["F]U=',H<7%;17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B
M)&1E<W1?;F%M92(N+BY=*3L**"1M96UB97(M/F5X=')A8W14;T9I;&5.86UE
M9"@D9&5S=%]N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I
M92!Q<5M%<G)O<B!E>'1R86-T:6YG('II<"!M96UB97(@=&\@(B1D97-T7VYA
M;64B73L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X
M(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI
M('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB
M+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P
M<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*
M+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T
M*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*
M<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L
M("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<
M+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T
M:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H
M(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR
M97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S
M=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER
M92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR
M97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q
M=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z
M.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U
M:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M
M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I
M9V5S=#HZ4TA!.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR
M97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R
M:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER
M92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E
M<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T[
M"F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L
M('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@
M<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A
M;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@
M*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^
M("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@
M;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$
M25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I
M"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A
M;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH
M)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@
M9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97
M:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD
M=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[
M55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*;7D@)'-T
M;7!D:7(@/2`B)'!A=&@D<WES>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@
M)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FUY("1C86-H95]D
M:7(["FEF("@D14Y6>U!!4E]#3$5!3GTI('L*)&-A8VAE7V1I<B`](")T96UP
M+20D(CL*?0IE;'-E('L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M
M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PII9B`H
M*&UY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@D9F@I*2`^/2`P*2![
M"G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L
M96YG=&@H(EPP0T%#2$4B*2P@,#L*;7D@)&)U9CL*<F5A9"`D9F@L("1B=68L
M(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*
M<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE
M;F=T:"@B7#!#04-(12(I"BT@)&-A8VAE7VYA;65?<VEZ92P@,#L*<F5A9"`D
M9F@L("1B=68L("1C86-H95]N86UE7W-I>F4["B1B=68@/7X@<R]<,"\O9SL*
M)&-A8VAE7V1I<B`](")C86-H92TD8G5F(CL*?0I]"F-L;W-E("1F:#L*?0II
M9B`H(21C86-H95]D:7(I('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*)$5.
M5GM005)?0TQ%04Y](#T@,3L*?0HD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L:6U]
M)&-A8VAE7V1I<B(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PHD14Y6>U!!4E]4
M14U0?2`]("1S=&UP9&ER.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%
M3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*
M<W5B(%]S879E7V%S('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]
M($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S
M("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD
M)"(["FUY("1F:#L**&]P96X@)&9H+"`G/CIR87<G+"`D=&5M<&YA;64I"B8F
M("AP<FEN="`D9F@@)&-O;G1E;G1S*0HF)B`H8VQO<V4@)&9H*0IO<B!D:64@
M<7%;17)R;W(@=W)I=&EN9R`B)'1E;7!N86UE(CH@)"%=.PIC:&UO9"`D;6]D
M92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA
M;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N
M("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D
M("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^
M("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P
M.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.
M5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G
M;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`K(#$I.PI]
M"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@
M)'-Y<WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D
M<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G
M;F%M921S>7-[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D<WES>U]E>&5].PIR
M971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421S>7-[<&%T
M:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[
M4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^
M(',O7%$D<WES>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1S
M>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB*2P@;&%S="D*:68@+7,@
M(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](CL**"@D<')O
M9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II
M9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I
M>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'
M3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/"`P
M*2!["B1P<F]G;F%M92`]("(N)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0IM
M>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D
M*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W
M9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_
M/5PN7"X_7%$D<WES>U]D96QI;7U<12DO)'!W9"1S>7-[7V1E;&EM?2\["B1%
M3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET
M7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*
M<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]
M"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'
M3D%-12`I("D@>PID96QE=&4@)$5.5GLB4$%27R1?(GT["GT*9F]R("AQ=R\@
M5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R)005)?)%\B?2`]
M("1%3E9[(E!!4E]'3$]"04Q?)%\B?2!I9B!E>&ES=',@)$5.5GLB4$%27T=,
M3T)!3%\D7R)].PI]"FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.
M5GM005)?0TQ%04Y].PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T
M.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92![
M"G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N
M9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O
M;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE
M>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]
M"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"90
M05(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7%;
M<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.
M;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&Y="G5N;&5S<R`M92`D<')O9VYA
M;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?
M5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T52
M4D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)2
M3U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I
M9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@!P97)L>'-I+F,````010$`3$(!
M```````,0P$`$$,!``1%`0!40@$`#$4!``````#P1`$`^$0!````````0T%#
M2$4``#T```!`````"P```$`````0````0````"8```!`````-0```$`````#
M````0`````8```!`````%````$`````.````0`````T```!`````)0```$``
M```2````0````"@```!``````@```$`````8````0`````D```!`````"@``
M`$```````````````,R0_W\!````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````#0%0$`J!4!```````!````!`,`
M``$````4`P```0```!X#```,````M`\!``T```!400$`&0```/S^`@`;````
M!````!H`````_P(`'`````0```#U_O]OM`$!``4```!4"0$`!@```.0$`0`*
M````4@,```L````0````%0`````````#```````#``(```#P`0``%````!$`
M```7````Q`T!`!$```"4#0$`$@```#`````3````"````/[__V\T#0$`____
M;P(```#P__]OI@P!````````````````````````````````````````````
M``````````````````````C_`@```````````,`/`0#`#P$`P`\!`,`/`0#`
M#P$`P`\!`,`/`0#`#P$`P`\!`,`/`0#`#P$`P`\!`,`/`0#`#P$`P`\!`,`/
M`0#`#P$`P`\!`,`/`0#`#P$`P`\!`,`/`0#`#P$`P`\!`,`/`0#`#P$`P`\!
M`,`/`0#`#P$`P`\!`,`/`0#`#P$`P`\!`,`/`0#`#P$`P`\!`,`/`0#`#P$`
MP`\!`,`/`0#`#P$`P`\!`,`/`0#`#P$`P`\!`,`/`0#`#P$`P`\!`,`/`0#`
M#P$`P`\!`,`/`0#`#P$`P`\!`,`/`0#`#P$`P`\!`,`/`0#`#P$`P`\!`,`/
M`0#`#P$```````````#`$@$````````````*4$%2+G!M"@`````810$`1T-#
M.B`H36%G96EA(#$R+C(N,2TP+C(P,C(Q,3$Y+C$N;6=A.2D@,3(N,BXQ(#(P
M,C(Q,3$X`$=#0SH@*$UA9V5I82`Q,BXR+C$M,"XR,#(R,3$R-BXQ+FUG83DI
M(#$R+C(N,2`R,#(R,3$R-@!!,@```&%E86)I``$H````!3<M00`&"@=!"`$)
M`@H$$@03`10!%0$7`Q@!&0$:`AP!(@$`+G-H<W1R=&%B`"YI;G1E<G``+FYO
M=&4N9VYU+F)U:6QD+6ED`"YN;W1E+D%"22UT86<`+F=N=2YH87-H`"YD>6YS
M>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;"YD
M>6X`+G)E;"YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N05)-+F5X
M:61X`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N9&%T82YR
M96PN<F\`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM96YT`"Y!4DTN
M871T<FEB=71E<P``````````````````````````````````````````````
M``````````L````!`````@```%0!`0!4`0``&0```````````````0``````
M```3````!P````(```!P`0$`<`$``"0```````````````0`````````)@``
M``<````"````E`$!`)0!```@```````````````$`````````#0```#V__]O
M`@```+0!`0"T`0``,`,```4`````````!`````0````^````"P````(```#D
M!`$`Y`0``'`$```&`````0````0````0````1@````,````"````5`D!`%0)
M``!2`P`````````````!`````````$X```#___]O`@```*8,`0"F#```C@``
M``4``````````@````(```!;````_O__;P(````T#0$`-`T``&`````&````
M`@````0`````````:@````D````"````E`T!`)0-```P````!0`````````$
M````"````',````)````0@```,0-`0#$#0``\`$```4````6````!`````@`
M``!\`````0````8```"T#P$`M`\```P```````````````0`````````=P``
M``$````&````P`\!`,`/``#\`@`````````````$````!````((````!````
M!@```,`2`0#`$@``E"X`````````````"`````````"(`````0````8```!4
M00$`5$$```@```````````````0`````````C@````$````"````7$$!`%Q!
M``"T0@`````````````$`````````)8````!``!P@@```!"$`0`0A```"```
M``T`````````!`````````"A`````0````(````8A`$`&(0```0`````````
M``````0`````````JP````X````#````_/X"`/S^```$```````````````$
M````!````+<````/`````P````#_`@``_P``!```````````````!`````0`
M``##`````0````,````$_P(`!/\```0```````````````0`````````T```
M``8````#````"/\"``C_``#X````!@`````````$````"````-D````!````
M`P```````P````$`$`$`````````````!`````0```#>`````0````,````0
M`0,`$`$!`!@```````````````0`````````Y`````@````#````*`$#`"@!
M`0`D```````````````(`````````.D````!````,``````````H`0$`;@``
M`````````````0````$```#R`````P``<```````````E@$!`#,`````````
M``````$``````````0````,``````````````,D!`0`"`0`````````````!
'````````````
